% file name:  PC_AA.m
% Double A-arm suspension
    clear all
    addpath Basics  PC_Basics  PC_AA
% Constant geometric data
    r_Q = [0.20; -0.14]; r_O = [0.32; 0.02];
    L_AQ = 0.42; L_BA = 0.22; L_BO = 0.26; L_CA = 0.14; L_CB = 0.18;
        els = [L_AQ  L_BA  L_BO  L_CA  L_CB];
% Coordinates
    r_A = [0.610; -0.233]; r_B = [0.578; -0.013]; r_C = [0.709; -0.132];
% Velocities
    r_A_d = [0.263; 1.163]; r_B_d = [0.146; 1.146]; r_C_d = [0.209; 1.216];    
% Compute position vectors
    d_AQ = r_A - r_Q; d_BA = r_B - r_A; d_BO = r_B - r_O;
    d_CA = r_C - r_A; d_CB = r_C - r_B;
        dees = [d_AQ d_BA d_BO d_CA d_CB];
% Evaluate constraints
    Phi = PC_AA_Phi(dees, els);
% Evaluate Jacobian
    D = PC_AA_jacob(dees);
% Compute velocity vectors
    d_AQ_d = r_A_d; d_BA_d = r_B_d - r_A_d; d_BO_d = r_B_d;
    d_CA_d = r_C_d - r_A_d; d_CB_d = r_C_d - r_B_d;
        dees_d = [d_AQ_d d_BA_d d_BO_d d_CA_d d_CB_d];
% Construct r-h-s array of acceleration constraints
    gamma = PC_AA_gamma(dees_d);
    
% Constant geometric data
    L_EQ = 0.24; r_F = [0.38; 0.04];
% Masses, gravitational constant, and spring-damper characteristics
    m_A = 7.27; m_B = 4.43; m_C = 19.80; g = 9.81;
    k = 91600; L_0 = 0.3; d_c = 1433;
    alpha_A = 0.57; alpha_Q = 0.43;    
% Construct f array
    % Compute coordinate and velocity of secondary point E
    r_E   = PC_secondary(r_Q, r_A, L_EQ, 0, L_AQ);
    r_E_d = PC_secondary([0; 0], r_A_d, L_EQ, 0, L_AQ);
    d_EF = r_E - r_F; d_EF_d = r_E_d;
    h = PC_AA_h(d_EF, d_EF_d, m_A, m_B, m_C, g, ...
                k, L_0, d_c, alpha_A);
% Construct mass matrix
        M_diag = [m_A m_A m_B m_B m_C m_C];
    M = diag(M_diag);

