% file name:  PC_MP.m
% MacPherson suspension
    clear all
    addpath Basics  PC_Basics  PC_MP
% Constant geometric data
    r_Q = [0.12; -0.41]; r_O = [0.41; 0.13];
    L_AQ = 0.45; L_AB = 0.36; L_CA = 0.12; L_CB = 0.39;
        els = [L_AQ  L_AB  L_CA  L_CB];
% Estimated coordinates
    r_A = [0.57; -0.41]; r_B = [0.468; -0.065]; r_C = [0.688; -0.387];
% Assume the following velocities
    r_A_d = [0; 1.130]; r_B_d = [-0.197; 1.072]; r_C_d = [-0.013; 1.197];
% Compute position vectors
    d_AQ = r_A - r_Q; d_AB = r_A - r_B; d_CA = r_C - r_A;
    d_CB = r_C - r_B; d_BO = r_B - r_O;
        dees = [d_AQ  d_AB  d_CA  d_CB  d_BO];
% Evaluate constraints
    Phi = PC_MP_Phi(dees, els);
% Construct Jacobian
    D = PC_MP_jacob(dees);
% Compute velocity vectors
    d_AQ_d = r_A_d; d_AB_d = r_A_d - r_B_d; d_CA_d = r_C_d - r_A_d;
    d_CB_d = r_C_d - r_B_d; d_BO_d = r_B_d;
        dees_d = [d_AQ_d d_AB_d d_CA_d d_CB_d d_BO_d];
% Construct r-h-s array of acceleration constraints
    gamma = PC_MP_gamma(dees_d);

% Masses, gravitational constant, and spring-damper data
    m_A = 13.98; m_B = 3.66; m_C = 3.36; g = 9.81;
    k = 22600; L_0 = 0.34; d_c = 1270;
% Construct h array
    h = PC_MP_h(d_BO, d_BO_d, m_A, m_B, m_C, g, k, L_0, d_c);
% Construct mass matrix
        M_diag = [m_A m_A m_B m_B m_C m_C];
    M = diag(M_diag);
